@@ -12,11 +12,11 @@ class Foo {
 
     method bar ($moo) { "outer(${moo})-" . inner() }
 
-    class Bar is mutable {
+    class ::Bar is mutable {
         method bar { blessed($_[0]) ? 0 : 1 }
     }
 
-    class Baz {
+    class ::Baz {
         method baz {}
     }
 }
